@@ -27,9 +27,9 @@ class DataSetsManager(ManagerMix):
     def data_set_by_code(self, site, element, aggregation, time_step, level = None, elementMarkOverride = None):
         if elementMarkOverride is not None:
             element = elementMarkOverride
-        code = element + "_" + aggregation + "_" + time_step
+        code = element + "_" + aggregation + "_" + str(time_step)
         if level is not None:
-            code += "_" + level
+            code += "_" + str(level)
         content = self.get(site.url + "/data-sets/" + code)
 
         return DataSets(**content, client=self._client, site=site)
