@@ -34,7 +34,7 @@ class ElementContextsManager(ManagerMix):
                 code += "_" + str(level_code)
             # if elementContext.aggregation == aggregation and elementContext.element.mark == element_mark and elementContext.time_step.code == timestamp_code and (level_code is None or (level_code is not None and elementContext.levelId is not None and elementContext.level.code == level_code)):
             #     return elementContext
-            if elementContext == code:
+            if elementContext.code == code:
                 return elementContext
 
         return None
