@@ -1,5 +1,5 @@
 from cgdb.utils.ManagerMix import ManagerMix
-from cgdb.recources.parameter import Parameter
+from cgdb.resources.parameter import Parameter
 
 
 class ParametersManager(ManagerMix):
